@@ -4,7 +4,7 @@ describe 'zaqar::db::postgresql' do
 
   shared_examples_for 'zaqar::db::postgresql' do
     let :req_params do
-      { :password => 'pw' }
+      { :password => 'zaqarpass' }
     end
 
     let :pre_condition do
@@ -16,9 +16,14 @@ describe 'zaqar::db::postgresql' do
         req_params
       end
 
-      it { is_expected.to contain_postgresql__server__db('zaqar').with(
-        :user     => 'zaqar',
-        :password => 'md52e9c9a1a01bb2fef7463b70dd24d4b25'
+      it { is_expected.to contain_class('zaqar::deps') }
+
+      it { is_expected.to contain_openstacklib__db__postgresql('zaqar').with(
+        :user       => 'zaqar',
+        :password   => 'zaqarpass',
+        :dbname     => 'zaqar',
+        :encoding   => nil,
+        :privileges => 'ALL',
       )}
     end
 
@@ -29,7 +34,11 @@ describe 'zaqar::db::postgresql' do
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
-        facts.merge!(OSDefaults.get_facts({ :concat_basedir => '/var/lib/puppet/concat' }))
+        facts.merge!(OSDefaults.get_facts({
+          # puppet-postgresql requires the service_provider fact provided by
+          # puppetlabs-postgresql.
+          :service_provider => 'systemd'
+        }))
       end
 
       it_configures 'zaqar::db::postgresql'
