@@ -4,13 +4,17 @@ describe 'zaqar::server' do
   shared_examples_for 'zaqar::server' do
     describe 'with a zaqar server enabled' do
       let :pre_condition do
-        "class {'::zaqar': admin_password => 'foo'}"
+        "class { 'zaqar::keystone::authtoken':
+           password =>'foo',
+         }
+         class {'::zaqar': }"
       end
 
       it { is_expected.to contain_service(platform_params[:zaqar_service_name]).with(
           :ensure => 'running',
           :enable => true
       )}
+      it { is_expected.to contain_class('zaqar::policy') }
 
     end
   end
@@ -24,9 +28,9 @@ describe 'zaqar::server' do
       end
 
       let(:platform_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
-          { :zaqar_service_name => 'zaqar' }
+          { :zaqar_service_name => 'zaqar-server' }
         when 'RedHat'
           { :zaqar_service_name => 'openstack-zaqar' }
         end
