@@ -9,13 +9,17 @@ describe 'zaqar::transport::websocket' do
           :bind  => '1',
           :port  => '2',
           :external_port  => '3',
+          :notification_bind  => '4',
+          :notification_port  => '5',
         }
       end
 
       it 'configures custom values' do
         is_expected.to contain_zaqar_config('drivers:transport:websocket/bind').with_value('1')
         is_expected.to contain_zaqar_config('drivers:transport:websocket/port').with_value('2')
-        is_expected.to contain_zaqar_config('drivers:transport:websocket/external-port').with_value('3')
+        is_expected.to contain_zaqar_config('drivers:transport:websocket/external_port').with_value('3')
+        is_expected.to contain_zaqar_config('drivers:transport:websocket/notification_bind').with_value('4')
+        is_expected.to contain_zaqar_config('drivers:transport:websocket/notification_port').with_value('5')
       end
     end
   end
